"""Code generated by Speakeasy (https://speakeasyapi.dev). DO NOT EDIT."""

from __future__ import annotations
from enum import Enum

class SdGenerationStyle(str, Enum):
    r"""The style to generate images with."""
    LEONARDO = 'LEONARDO'
    NONE = 'NONE'
